import Vue from 'vue';
import VueRouter from 'vue-router';

import Layout from '@/layouts';
import Login from '@/views/login';
import store from '@/store';

import { Loading } from 'element-ui';

Vue.use(VueRouter);

const routes = [
  {
    path: '/login',
    component: Login
  },
  {
    path: '/404',
    component: () => import('@/views/404')
  },
  {
    path: '/EnterSys',
    beforeEnter: (to, from, next) => {
      let loadingInstance = Loading.service({
        text: '跳转中...'
      });
      store
        .dispatch('user/enterSys', { access_code: to.query.AccessCode })
        .then(() => {
          loadingInstance.close();
          next('/');
        })
        .catch(() => {
          store.dispatch('user/signOut');
          loadingInstance.close();
          next('/login');
        });
    }
  },
  {
    path: '/',
    component: Layout,
    redirect: '/main',
    children: [
      {
        path: '/main',
        name: 'Main',
        component: () => import('@/views/teacher/main')
      }
    ]
  },
  // 创建课程
  {
    path: '/create_course',
    component: Layout,
    redirect: '/create_course/index',
    meta: { title: '课程列表' },
    children: [
      {
        path: '/create_course/index',
        component: () => import('@/views/teacher/create_course/index'),
        meta: { title: '创建课程' }
      }
    ]
  },
  {
    path: '/create_course_step_table',
    component: Layout,
    redirect: '/create_course_step_table/course_info',
    children: [
      {
        path: '/create_course_step_table/course_info',
        component: () => import('@/views/teacher/create_course/step_table/CourseInfo')
      },
      {
        path: '/create_course_step_table/select_book/:id',
        name: 'SelectBook',
        component: () => import('@/views/teacher/create_course/step_table/SelectBook')
      },
      {
        path: '/create_course_step_table/create_task/:id',
        component: () => import('@/views/teacher/create_course/step_table/CreateTask')
      }
    ]
  },
  {
    path: '/cs_item_detail',
    component: Layout,
    redirect: '/cs_item_detail/index/:id',
    children: [
      {
        path: '/cs_item_detail/index/:id',
        name: 'CSItemDetail',
        component: () => import('@/views/teacher/cs_item_detail')
      }
    ]
  },
  {
    path: '/add_course',
    component: Layout,
    redirect: '/add_course/index',
    children: [
      {
        path: '/add_course/index',
        name: 'AddCourse',
        component: () => import('@/views/teacher/add_course')
      }
    ]
  },
  {
    path: '/live',
    component: Layout,
    redirect: '/live/teacher',
    children: [
      {
        path: '/live/teacher',
        name: 'TeacherLive',
        component: () => import('@/views/live')
      }
    ]
  },
  {
    path: '*',
    redirect: '/404'
  }
];

const createRouter = () =>
  new VueRouter({
    // mode: 'history',
    scrollBehavior: () => ({ y: 0 }),
    routes
  });

const router = createRouter();

// 重置路由
export function resetRouter() {
  const newRouter = createRouter();
  router.matcher = newRouter.matcher;
}

export default router;
